@@ -9,6 +9,7 @@ export function parseData(sceneData, actions, catalog) {
   planData.sceneGraph = {
     unit: sceneData.unit,
     layers: {},
+    busyResources: { layers: {} },
     width: sceneData.width,
     height: sceneData.height,
     LODs: {}
@@ -29,7 +30,7 @@ export function parseData(sceneData, actions, catalog) {
   });
 
   Promise.all(promises).then(function (value) {
-    updateBoundingBox(planData);
+    return updateBoundingBox(planData);
   });
 
   return planData;
@@ -49,6 +50,14 @@ function createLayerObjects(layer, planData, sceneData, actions, catalog) {
     altitude: layer.altitude
   };
 
+  planData.sceneGraph.busyResources.layers[layer.id] = {
+    id: layer.id,
+    lines: {},
+    holes: {},
+    areas: {},
+    items: {}
+  };
+
   // Import lines
   layer.lines.forEach(function (line) {
     promises.push(addLine(sceneData, planData, layer, line.id, catalog, actions.linesActions));
@@ -73,11 +82,10 @@ function createLayerObjects(layer, planData, sceneData, actions, catalog) {
 export function updateScene(planData, sceneData, oldSceneData, diffArray, actions, catalog) {
 
   filterDiffs(diffArray, sceneData, oldSceneData).forEach(function (diff) {
-
     /* First of all I need to find the object I need to update */
-    var modifiedPath = diff.path.split("/");
+    var modifiedPath = diff.path.split('/');
 
-    if (modifiedPath[1] === "layers") {
+    if (modifiedPath[1] === 'layers') {
 
       var layer = sceneData[modifiedPath[1]].get(modifiedPath[2]);
 
@@ -111,7 +119,7 @@ export function updateScene(planData, sceneData, oldSceneData, diffArray, action
         // I need to create the objects for this layer
         var promises = createLayerObjects(sceneData.layers.get(layerSelectedID), planData, sceneData, actions, catalog);
         Promise.all(promises).then(function (values) {
-          updateBoundingBox(planData);
+          return updateBoundingBox(planData);
         });
       }
 
@@ -141,47 +149,102 @@ function replaceObject(modifiedPath, layer, planData, actions, sceneData, oldSce
   var promises = [];
 
   switch (modifiedPath[3]) {
-    case "vertices":
-      break;
-    case "holes":
-      var newHoleData = layer.holes.get(modifiedPath[4]);
-      var lineID = newHoleData.line;
-      if (modifiedPath[5] === 'selected') {
-        // I remove only the hole without removing the wall
-        removeHole(planData, layer.id, newHoleData.id);
-        promises.push(addHole(sceneData, planData, layer, newHoleData.id, catalog, actions.holesActions));
-      } else {
-        layer.lines.get(lineID).holes.forEach(function (holeID) {
-          removeHole(planData, layer.id, holeID);
-        });
-        removeLine(planData, layer.id, lineID);
-        promises.push(addLine(sceneData, planData, layer, lineID, catalog, actions.linesActions));
-        layer.lines.get(lineID).holes.forEach(function (holeID) {
-          promises.push(addHole(sceneData, planData, layer, holeID, catalog, actions.holesActions));
-        });
+    case 'vertices':
+      if (modifiedPath[5] !== 'selected') {
+        var vertex = layer.vertices.get(modifiedPath[4]);
+
+        if (modifiedPath[5] === 'x' || modifiedPath[5] === 'y') {
+          vertex.lines.forEach(function (lineID) {
+            return replaceObject([0, 0, 0, 'lines', lineID], layer, planData, actions, sceneData, oldSceneData, catalog);
+          });
+        }
+
+        if (modifiedPath[5] === 'areas') {
+          var areaID = vertex.areas.get(~~modifiedPath[6]);
+          replaceObject([0, 0, 0, 'areas', areaID], layer, planData, actions, sceneData, oldSceneData, catalog);
+        }
       }
       break;
-    case "lines":
-      removeLine(planData, layer.id, modifiedPath[4]);
-      promises.push(addLine(sceneData, planData, layer, modifiedPath[4], catalog, actions.linesActions));
+    case 'holes':
+      var newHoleData = layer.holes.get(modifiedPath[4]);
+
+      if (catalog.getElement(newHoleData.type).updateRender3D) {
+        promises.push(updateHole(sceneData, oldSceneData, planData, layer, modifiedPath[4], modifiedPath.slice(5), catalog, actions.holesActions, function () {
+          return removeHole(planData, layer.id, newHoleData.id);
+        }, function () {
+          return addHole(sceneData, planData, layer, newHoleData.id, catalog, actions.holesActions);
+        }));
+      } else {
+        var lineID = newHoleData.line;
+        if (modifiedPath[5] === 'selected') {
+          // I remove only the hole without removing the wall
+          removeHole(planData, layer.id, newHoleData.id);
+          promises.push(addHole(sceneData, planData, layer, newHoleData.id, catalog, actions.holesActions));
+        } else {
+          layer.lines.get(lineID).holes.forEach(function (holeID) {
+            removeHole(planData, layer.id, holeID);
+          });
+          removeLine(planData, layer.id, lineID);
+          promises.push(addLine(sceneData, planData, layer, lineID, catalog, actions.linesActions));
+          layer.lines.get(lineID).holes.forEach(function (holeID) {
+            promises.push(addHole(sceneData, planData, layer, holeID, catalog, actions.holesActions));
+          });
+        }
+      }
       break;
-    case "areas":
-      removeArea(planData, layer.id, modifiedPath[4]);
-      promises.push(addArea(sceneData, planData, layer, modifiedPath[4], catalog, actions.areaActions));
+    case 'lines':
+      var line = layer.lines.get(modifiedPath[4]);
+
+      if (catalog.getElement(line.type).updateRender3D) {
+        promises.push(updateLine(sceneData, oldSceneData, planData, layer, modifiedPath[4], modifiedPath.slice(5), catalog, actions.linesActions, function () {
+          return removeLine(planData, layer.id, modifiedPath[4]);
+        }, function () {
+          return addLine(sceneData, planData, layer, modifiedPath[4], catalog, actions.linesActions);
+        }));
+      } else {
+        removeLine(planData, layer.id, modifiedPath[4]);
+        promises.push(addLine(sceneData, planData, layer, modifiedPath[4], catalog, actions.linesActions));
+      }
       break;
-    case "items":
-      removeItem(planData, layer.id, modifiedPath[4]);
-      promises.push(addItem(sceneData, planData, layer, modifiedPath[4], catalog, actions.itemsActions));
+    case 'areas':
+      var area = layer.areas.get(modifiedPath[4]);
+
+      if (catalog.getElement(area.type).updateRender3D) {
+        promises.push(updateArea(sceneData, oldSceneData, planData, layer, modifiedPath[4], modifiedPath.slice(5), catalog, actions.areaActions, function () {
+          return removeArea(planData, layer.id, modifiedPath[4]);
+        }, function () {
+          return addArea(sceneData, planData, layer, modifiedPath[4], catalog, actions.areaActions);
+        }));
+      } else {
+        if (planData.sceneGraph.layers[layer.id].areas[modifiedPath[4]]) {
+          removeArea(planData, layer.id, modifiedPath[4]);
+        }
+        promises.push(addArea(sceneData, planData, layer, modifiedPath[4], catalog, actions.areaActions));
+      }
+      break;
+    case 'items':
+      var item = layer.items.get(modifiedPath[4]);
+
+      if (catalog.getElement(item.type).updateRender3D) {
+        promises.push(updateItem(sceneData, oldSceneData, planData, layer, modifiedPath[4], modifiedPath.slice(5), catalog, actions.itemsActions, function () {
+          return removeItem(planData, layer.id, modifiedPath[4]);
+        }, function () {
+          return addItem(sceneData, planData, layer, modifiedPath[4], catalog, actions.linesActions);
+        }));
+      } else {
+        removeItem(planData, layer.id, modifiedPath[4]);
+        promises.push(addItem(sceneData, planData, layer, modifiedPath[4], catalog, actions.itemsActions));
+      }
       break;
 
-    case "visible":
+    case 'visible':
       if (!layer.visible) {
         var _layerGraph = planData.sceneGraph.layers[layer.id];
 
         for (var _lineID in _layerGraph.lines) {
           removeLine(planData, layer.id, _lineID);
-        }for (var areaID in _layerGraph.areas) {
-          removeArea(planData, layer.id, areaID);
+        }for (var _areaID in _layerGraph.areas) {
+          removeArea(planData, layer.id, _areaID);
         }for (var itemID in _layerGraph.items) {
           removeItem(planData, layer.id, itemID);
         }for (var holeID in _layerGraph.holes) {
@@ -193,13 +256,13 @@ function replaceObject(modifiedPath, layer, planData, actions, sceneData, oldSce
 
       break;
 
-    case "opacity":
-    case "altitude":
+    case 'opacity':
+    case 'altitude':
       var layerGraph = planData.sceneGraph.layers[layer.id];
       for (var _lineID2 in layerGraph.lines) {
         removeLine(planData, layer.id, _lineID2);
-      }for (var _areaID in layerGraph.areas) {
-        removeArea(planData, layer.id, _areaID);
+      }for (var _areaID2 in layerGraph.areas) {
+        removeArea(planData, layer.id, _areaID2);
       }for (var _itemID in layerGraph.items) {
         removeItem(planData, layer.id, _itemID);
       }for (var _holeID in layerGraph.holes) {
@@ -208,7 +271,7 @@ function replaceObject(modifiedPath, layer, planData, actions, sceneData, oldSce
 
   }
   Promise.all(promises).then(function (values) {
-    updateBoundingBox(planData);
+    return updateBoundingBox(planData);
   });
 }
 
@@ -216,7 +279,7 @@ function removeObject(modifiedPath, layer, planData, actions, sceneData, oldScen
 
   var promises = [];
   switch (modifiedPath[3]) {
-    case "lines":
+    case 'lines':
       // Here I remove the line with all its holes
       var lineID = modifiedPath[4];
       var oldLayer = oldSceneData.layers.get(layer.id);
@@ -232,13 +295,13 @@ function removeObject(modifiedPath, layer, planData, actions, sceneData, oldScen
         });
       }
       break;
-    case "areas":
+    case 'areas':
       if (modifiedPath.length === 5) {
         // I am removing an entire area
         removeArea(planData, layer.id, modifiedPath[4]);
       }
       break;
-    case "items":
+    case 'items':
       if (modifiedPath.length === 5) {
         // I am removing an item
         removeItem(planData, layer.id, modifiedPath[4]);
@@ -247,7 +310,7 @@ function removeObject(modifiedPath, layer, planData, actions, sceneData, oldScen
   }
 
   Promise.all(promises).then(function (values) {
-    updateBoundingBox(planData);
+    return updateBoundingBox(planData);
   });
 }
 
@@ -265,65 +328,123 @@ function removeLayer(layerId, planData) {
   }delete planData.sceneGraph.layers[layerId];
 }
 
-function removeHole(planData, layerId, holeToRemoveID) {
-  var holeToRemove = planData.sceneGraph.layers[layerId].holes[holeToRemoveID];
-  planData.plan.remove(holeToRemove);
-  disposeObject(holeToRemove);
-  delete planData.sceneGraph.layers[layerId].holes[holeToRemoveID];
-  delete planData.sceneGraph.LODs[holeToRemoveID];
+function removeHole(planData, layerId, holeID) {
 
-  holeToRemove = null;
-  updateBoundingBox(planData);
+  if (planData.sceneGraph.busyResources.layers[layerId].holes[holeID]) {
+    setTimeout(function () {
+      return removeHole(planData, layerId, holeID);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].holes[holeID] = true;
+
+  var hole3D = planData.sceneGraph.layers[layerId].holes[holeID];
+
+  if (hole3D) {
+    planData.plan.remove(hole3D);
+    disposeObject(hole3D);
+    delete planData.sceneGraph.layers[layerId].holes[holeID];
+    delete planData.sceneGraph.LODs[holeID];
+    hole3D = null;
+    updateBoundingBox(planData);
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].holes[holeID] = false;
 }
 
 function removeLine(planData, layerId, lineID) {
+
+  if (planData.sceneGraph.busyResources.layers[layerId].lines[lineID]) {
+    setTimeout(function () {
+      return removeLine(planData, layerId, lineID);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].lines[lineID] = true;
+
   var line3D = planData.sceneGraph.layers[layerId].lines[lineID];
 
-  planData.plan.remove(line3D);
-  disposeObject(line3D);
-  delete planData.sceneGraph.layers[layerId].lines[lineID];
-  delete planData.sceneGraph.LODs[lineID];
-  line3D = null;
-  updateBoundingBox(planData);
+  if (line3D) {
+    planData.plan.remove(line3D);
+    disposeObject(line3D);
+    delete planData.sceneGraph.layers[layerId].lines[lineID];
+    delete planData.sceneGraph.LODs[lineID];
+    line3D = null;
+    updateBoundingBox(planData);
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].lines[lineID] = false;
 }
 
 function removeArea(planData, layerId, areaID) {
+
+  if (planData.sceneGraph.busyResources.layers[layerId].areas[areaID]) {
+    setTimeout(function () {
+      return removeArea(planData, layerId, areaID);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].areas[areaID] = true;
+
   var area3D = planData.sceneGraph.layers[layerId].areas[areaID];
-  planData.plan.remove(area3D);
-  disposeObject(area3D);
-  delete planData.sceneGraph.layers[layerId].areas[areaID];
-  delete planData.sceneGraph.LODs[areaID];
-  area3D = null;
-  updateBoundingBox(planData);
+
+  if (area3D) {
+    planData.plan.remove(area3D);
+    disposeObject(area3D);
+    delete planData.sceneGraph.layers[layerId].areas[areaID];
+    delete planData.sceneGraph.LODs[areaID];
+    area3D = null;
+    updateBoundingBox(planData);
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].areas[areaID] = false;
 }
 
 function removeItem(planData, layerId, itemID) {
+
+  if (planData.sceneGraph.busyResources.layers[layerId].items[itemID]) {
+    setTimeout(function () {
+      return removeItem(planData, layerId, itemID);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].items[itemID] = true;
+
   var item3D = planData.sceneGraph.layers[layerId].items[itemID];
-  planData.plan.remove(item3D);
-  disposeObject(item3D);
-  delete planData.sceneGraph.layers[layerId].items[itemID];
-  delete planData.sceneGraph.LODs[itemID];
-  item3D = null;
-  updateBoundingBox(planData);
+
+  if (item3D) {
+    planData.plan.remove(item3D);
+    disposeObject(item3D);
+    delete planData.sceneGraph.layers[layerId].items[itemID];
+    delete planData.sceneGraph.LODs[itemID];
+    item3D = null;
+    updateBoundingBox(planData);
+  }
+
+  planData.sceneGraph.busyResources.layers[layerId].items[itemID] = false;
 }
 
 function addObject(modifiedPath, layer, planData, actions, sceneData, oldSceneData, catalog) {
 
   var promises = [];
   switch (modifiedPath[3]) {
-    case "lines":
+    case 'lines':
       if (modifiedPath.length === 5) {
         // I have to add a line
         promises.push(addLine(sceneData, planData, layer, modifiedPath[4], catalog, actions.linesActions));
       }
       break;
-    case "areas":
+    case 'areas':
       if (modifiedPath.length === 5) {
         // I have to add an area
         promises.push(addArea(sceneData, planData, layer, modifiedPath[4], catalog, actions.areaActions));
       }
       break;
-    case "items":
+    case 'items':
       if (modifiedPath.length === 5) {
         // I have to add an area
         promises.push(addItem(sceneData, planData, layer, modifiedPath[4], catalog, actions.itemsActions));
@@ -332,7 +453,7 @@ function addObject(modifiedPath, layer, planData, actions, sceneData, oldSceneDa
   }
 
   Promise.all(promises).then(function (values) {
-    updateBoundingBox(planData);
+    return updateBoundingBox(planData);
   });
 }
 
@@ -392,7 +513,28 @@ function addHole(sceneData, planData, layer, holeID, catalog, holesActions) {
   });
 }
 
+function updateHole(sceneData, oldSceneData, planData, layer, holeID, differences, catalog, holesActions, selfDestroy, selfBuild) {
+
+  var hole = layer.holes.get(holeID);
+  var oldHole = oldSceneData.layers.get(layer.id).holes.get(holeID);
+  var mesh = planData.sceneGraph.layers[layer.id].holes[holeID];
+
+  if (!mesh) return null;
+
+  return catalog.getElement(hole.type).updateRender3D(hole, layer, sceneData, mesh, oldHole, differences, selfDestroy, selfBuild);
+}
+
 function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
+
+  if (planData.sceneGraph.busyResources.layers[layer.id].lines[lineID]) {
+    setTimeout(function () {
+      return addLine(sceneData, planData, layer, lineID, catalog, linesActions);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layer.id].lines[lineID] = true;
+
   var line = layer.lines.get(lineID);
 
   // First of all I need to find the vertices of this line
@@ -430,13 +572,35 @@ function addLine(sceneData, planData, layer, lineID, catalog, linesActions) {
       opacity = 1;
     }
     applyOpacity(pivot, opacity);
+    planData.sceneGraph.busyResources.layers[layer.id].lines[lineID] = false;
   });
 }
 
+function updateLine(sceneData, oldSceneData, planData, layer, lineID, differences, catalog, linesActions, selfDestroy, selfBuild) {
+
+  var line = layer.lines.get(lineID);
+  var oldLine = oldSceneData.layers.get(layer.id).lines.get(lineID);
+  var mesh = planData.sceneGraph.layers[layer.id].lines[lineID];
+
+  if (!mesh) return null;
+
+  return catalog.getElement(line.type).updateRender3D(line, layer, sceneData, mesh, oldLine, differences, selfDestroy, selfBuild);
+}
+
 function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
+
+  if (planData.sceneGraph.busyResources.layers[layer.id].areas[areaID]) {
+    setTimeout(function () {
+      return addArea(sceneData, planData, layer, areaID, catalog, areaActions);
+    }, 100);
+    return;
+  }
+
+  planData.sceneGraph.busyResources.layers[layer.id].areas[areaID] = true;
+
   var area = layer.areas.get(areaID);
   var interactFunction = function interactFunction() {
-    areaActions.selectArea(layer.id, area.id);
+    return areaActions.selectArea(layer.id, areaID);
   };
 
   return catalog.getElement(area.type).render3D(area, layer, sceneData).then(function (area3D) {
@@ -449,7 +613,7 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
     pivot.add(area3D);
     pivot.position.y = layer.altitude;
     planData.plan.add(pivot);
-    planData.sceneGraph.layers[layer.id].areas[area.id] = pivot;
+    planData.sceneGraph.layers[layer.id].areas[areaID] = pivot;
 
     applyInteract(pivot, interactFunction);
 
@@ -459,9 +623,21 @@ function addArea(sceneData, planData, layer, areaID, catalog, areaActions) {
     }
 
     applyOpacity(pivot, opacity);
+    planData.sceneGraph.busyResources.layers[layer.id].areas[areaID] = false;
   });
 }
 
+function updateArea(sceneData, oldSceneData, planData, layer, areaID, differences, catalog, areaActions, selfDestroy, selfBuild) {
+
+  var area = layer.areas.get(areaID);
+  var oldArea = oldSceneData.layers.get(layer.id).areas.get(areaID);
+  var mesh = planData.sceneGraph.layers[layer.id].areas[areaID];
+
+  if (!mesh) return null;
+
+  return catalog.getElement(area.type).updateRender3D(area, layer, sceneData, mesh, oldArea, differences, selfDestroy, selfBuild);
+}
+
 function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
 
   var item = layer.items.get(itemID);
@@ -496,6 +672,17 @@ function addItem(sceneData, planData, layer, itemID, catalog, itemsActions) {
   });
 }
 
+function updateItem(sceneData, oldSceneData, planData, layer, itemID, differences, catalog, itemsActions) {
+
+  var item = layer.items.get(itemID);
+  var oldItem = oldSceneData.layers.get(layer.id).items.get(itemID);
+  var mesh = planData.sceneGraph.layers[layer.id].items[itemID];
+
+  if (!mesh) return null;
+
+  return catalog.getElement(item.type).updateRender3D(item, layer, sceneData, mesh, oldItem, differences);
+}
+
 // Apply interact function to children of an Object3D
 function applyInteract(object, interactFunction) {
   object.traverse(function (child) {
@@ -582,7 +769,7 @@ function minimizeRemoveDiffsWhenSwitchingLayers(diffArray, sceneData, oldSceneDa
   var foundDiff = void 0;
   var i = void 0;
   for (i = 0; i < diffArray.length && !foundDiff; i++) {
-    if (diffArray[i].path === "/selectedLayer") {
+    if (diffArray[i].path === '/selectedLayer') {
       foundDiff = diffArray[i];
     }
   }
@@ -591,7 +778,7 @@ function minimizeRemoveDiffsWhenSwitchingLayers(diffArray, sceneData, oldSceneDa
     if (!sceneData.layers.get(oldSceneData.selectedLayer).visible) {
       return diffArray.filter(function (diff) {
 
-        return !(diff.path.endsWith("/selected") && diff.path.startsWith("/layers/" + oldSceneData.selectedLayer)) && !(diff.op === "remove" && diff.path.includes(oldSceneData.selectedLayer));
+        return !(diff.path.endsWith('/selected') && diff.path.startsWith('/layers/' + oldSceneData.selectedLayer)) && !(diff.op === 'remove' && diff.path.includes(oldSceneData.selectedLayer));
       });
     }
   }
@@ -637,7 +824,7 @@ function minimizeChangePropertiesDiffs(diffArray, sceneData, oldSceneData) {
     var split = diff.path.split('/');
     if (split[5] === 'properties') {
       return idsFound[split[4]] ? false : idsFound[split[4]] = true;
-    } else if (split[5] === "misc") {
+    } else if (split[5] === 'misc') {
       // Remove misc changes
       return false;
     }
